==> org-lsst-ccs-buses-definition-6.1.8-sources.jar: org/lsst/ccs/bus/data/CCSVersions.java <==
package org.lsst.ccs.bus.data;

import java.io.Serializable;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Utility class that encapsulates all the versions of the Agents on the
 * CCS Environment
 * 
 * @author The LSST CCS Team
 * 
 */
public final class CCSVersions implements Serializable {
    
    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 234234597100235235L;
    
    private final Map<AgentInfo,DistributionInfo> map = new ConcurrentHashMap<>();
    
    
    /**
     * Default constructor.
     */
    public CCSVersions() {}
    
    /**
     * Copy constructor.
     * @param versions The object to copy.
     */
    public CCSVersions(CCSVersions versions) {
        this.map.putAll(versions.map);        
    }
    
    /**
     * Add a new AgentInfo, DistributionInfo pair.
     * 
     * @param agent The AgentInfo
     * @param distInfo The DistributionInfo
     */
    public void add(AgentInfo agent, DistributionInfo distInfo) {
        map.put(agent, distInfo);
    }
    
    /**
     * Remove an AgentInfo.
     * @param agent The AgentInfo
     * 
     */
    public void remove(AgentInfo agent) {
        map.remove(agent);
    }
    
    /**
     * Get the DistributionInfo for a given AgentInfo.
     * 
     * @param agent The AgentInfo for which to get the DistributionInfo.
     * @return The DistributionInfo for the provided AgentInfo.
     */
    public DistributionInfo getDistributionInfo(AgentInfo agent) {
        return map.get(agent);
    }
    
    /**
     * Get the DistributionInfo for a given agent by name.
     * 
     * @param agent The name of the for which to get the DistributionInfo.
     * @return The DistributionInfo for the provided AgentInfo.
     */
    public DistributionInfo getDistributionInfo(String agent) {
        for (AgentInfo a : map.keySet()) {
            if ( a.getName().equals(agent) ) {
                return map.get(a);
            }
        }
        return null;
    }
    
    /**
     * Get the Set of AgentInfo contained in this class.
     * 
     * @return The Set of AgentInfo contained in the class.
     */
    public Set<AgentInfo> getAgents() {
        return map.keySet();
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        for (AgentInfo a : getAgents() ) {
            sb.append("Agent "+a.getName()+"("+a.getType()+")\n");
            sb.append(getDistributionInfo(a).toString());
        }
        return sb.toString();
    }
    
    
}

==> org-lsst-ccs-buses-definition-6.2.8-20250521.162314-4-sources.jar: org/lsst/ccs/bus/data/CCSVersions.java <==
package org.lsst.ccs.bus.data;

import java.io.Serializable;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Utility class that encapsulates all the versions of the Agents on the
 * CCS Environment
 * 
 * @author The LSST CCS Team
 * 
 * @deprecated This class no longer needs to be in the buses package since it's no longer published.
 */
@Deprecated
public final class CCSVersions implements Serializable {
    
    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = 234234597100235235L;
    
    private final Map<AgentInfo,DistributionInfo> map = new ConcurrentHashMap<>();
    
    
    /**
     * Default constructor.
     */
    public CCSVersions() {}
    
    /**
     * Copy constructor.
     * @param versions The object to copy.
     */
    public CCSVersions(CCSVersions versions) {
        this.map.putAll(versions.map);        
    }
    
    /**
     * Add a new AgentInfo, DistributionInfo pair.
     * 
     * @param agent The AgentInfo
     * @param distInfo The DistributionInfo
     */
    public void add(AgentInfo agent, DistributionInfo distInfo) {
        map.put(agent, distInfo);
    }
    
    /**
     * Remove an AgentInfo.
     * @param agent The AgentInfo
     * 
     */
    public void remove(AgentInfo agent) {
        map.remove(agent);
    }
    
    /**
     * Get the DistributionInfo for a given AgentInfo.
     * 
     * @param agent The AgentInfo for which to get the DistributionInfo.
     * @return The DistributionInfo for the provided AgentInfo.
     */
    public DistributionInfo getDistributionInfo(AgentInfo agent) {
        return map.get(agent);
    }
    
    /**
     * Get the DistributionInfo for a given agent by name.
     * 
     * @param agent The name of the for which to get the DistributionInfo.
     * @return The DistributionInfo for the provided AgentInfo.
     */
    public DistributionInfo getDistributionInfo(String agent) {
        for (AgentInfo a : map.keySet()) {
            if ( a.getName().equals(agent) ) {
                return map.get(a);
            }
        }
        return null;
    }
    
    /**
     * Get the Set of AgentInfo contained in this class.
     * 
     * @return The Set of AgentInfo contained in the class.
     */
    public Set<AgentInfo> getAgents() {
        return map.keySet();
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        for (AgentInfo a : getAgents() ) {
            sb.append("Agent "+a.getName()+"("+a.getType()+")\n");
            sb.append(getDistributionInfo(a).toString());
        }
        return sb.toString();
    }
    
    
}
